@@ -1,6 +1,6 @@
 use std::collections::HashMap;
 use std::fmt::{Display, Formatter};
-use std::fs;
+
 use std::path::{Path, PathBuf};
 use std::time::Duration;
 
@@ -12,7 +12,7 @@ use toml_edit::{table, value, Array, Document, Item, Value};
 
 use crate::config::config_file::{ConfigFile, ConfigFileType};
 use crate::config::settings::SettingsBuilder;
-use crate::config::{config_file, AliasMap, MissingRuntimeBehavior};
+use crate::config::{config_file, global_config_files, AliasMap, MissingRuntimeBehavior};
 use crate::errors::Error::UntrustedConfig;
 use crate::file::create_dir_all;
 use crate::plugins::{unalias_plugin, PluginName};
@@ -21,7 +21,7 @@ use crate::toolset::{
     ToolSource, ToolVersionList, ToolVersionOptions, ToolVersionRequest, Toolset,
 };
 use crate::ui::prompt;
-use crate::{dirs, env, parse_error};
+use crate::{dirs, env, file, parse_error};
 
 #[derive(Debug, Default)]
 pub struct RtxToml {
@@ -58,21 +58,11 @@ impl RtxToml {
     pub fn from_file(path: &Path, is_trusted: bool) -> Result<Self> {
         trace!("parsing: {}", path.display());
         let mut rf = Self::init(path, is_trusted);
-        let body = fs::read_to_string(path).suggestion("ensure file exists and can be read")?;
+        let body = file::read_to_string(path).suggestion("ensure file exists and can be read")?;
         rf.parse(&body)?;
         Ok(rf)
     }
 
-    pub fn migrate(path: &Path, is_trusted: bool) -> Result<RtxToml> {
-        // attempt to read as new .rtx.toml syntax
-        let mut raw = String::from("[settings]\n");
-        raw.push_str(&fs::read_to_string(path)?);
-        let mut toml = RtxToml::init(path, is_trusted);
-        toml.parse(&raw)?;
-        toml.save()?;
-        Ok(toml)
-    }
-
     fn parse(&mut self, s: &str) -> Result<()> {
         let doc: Document = s.parse().suggestion("ensure file is valid TOML")?;
         for (k, v) in doc.iter() {
@@ -429,6 +419,7 @@ impl RtxToml {
                         }
                         "log_level" => settings.log_level = Some(self.parse_log_level(&k, v)?),
                         "raw" => settings.raw = Some(self.parse_bool(&k, v)?),
+                        "yes" => settings.yes = Some(self.parse_bool(&k, v)?),
                         _ => Err(eyre!("Unknown config setting: {}", k))?,
                     };
                 }
@@ -744,7 +735,7 @@ impl ConfigFile for RtxToml {
         if let Some(parent) = self.path.parent() {
             create_dir_all(parent)?;
         }
-        Ok(fs::write(&self.path, contents)?)
+        file::write(&self.path, contents)
     }
 
     fn dump(&self) -> String {
@@ -769,6 +760,10 @@ impl ConfigFile for RtxToml {
             None => vec![self.path.clone()],
         }
     }
+
+    fn is_global(&self) -> bool {
+        global_config_files().iter().any(|p| p == &self.path)
+    }
 }
 
 #[cfg(test)]
