@@ -1,12 +1,13 @@
+use color_eyre::eyre::ErrReport;
 use std::env::{join_paths, split_paths};
+use std::fs;
 use std::os::unix::fs::PermissionsExt;
 use std::path::PathBuf;
-use std::{fs, io};
 
 use indoc::formatdoc;
 use once_cell::sync::OnceCell;
 
-use crate::env;
+use crate::{env, file};
 
 pub fn setup() -> color_eyre::Result<PathBuf> {
     static SETUP: OnceCell<PathBuf> = OnceCell::new();
@@ -14,8 +15,8 @@ pub fn setup() -> color_eyre::Result<PathBuf> {
         let path = env::RTX_DATA_DIR.join(".fake-asdf");
         let asdf_bin = path.join("asdf");
         if !asdf_bin.exists() {
-            fs::create_dir_all(&path)?;
-            fs::write(
+            file::create_dir_all(&path)?;
+            file::write(
                 &asdf_bin,
                 // rtx="${{RTX_EXE:-rtx}}"
                 formatdoc! {r#"
@@ -28,7 +29,7 @@ pub fn setup() -> color_eyre::Result<PathBuf> {
             perms.set_mode(0o755);
             fs::set_permissions(&asdf_bin, perms)?;
         }
-        Ok::<PathBuf, io::Error>(path)
+        Ok::<PathBuf, ErrReport>(path)
     })?;
 
     Ok(path.clone())
